# Release information about releasemanager

version = "1.01"

description = "Allows simple, extensible, distributed release management for complex environments."
long_description = """
ReleaseManager is a simple, extensible way to manage software releases for complex environments.  If you have a need to manage a dozen or more code bases,
 each with unique build procedures, many of which produce resources that must be installed multiple machines, for multiple environments (prod, dev, qa, etc), then you've come across the same problems releasemanager is designed to solve.
 The administrative overhead of managing so many applications, different permission levels to different environments for different groups, unique build and install environments, sometimes with more than one per piece of hardware, can present developers and administrators with more work than is feasible for them to maintain.  ReleaseManager endeavors to ease that burden.
"""
author = "James Taylor"
email = "baldtrol@gmail.com"
copyright = "Copyright (c) 2007 James C. Taylor"

url = "http://code.google.com/p/releasemanager/"
download_url = "http://releasemanager.googlecode.com/svn/trunk/"
license = "MIT"
